@@ -9,7 +9,7 @@ def sleep_well(working_dir: str, logger, options: dict = None):
 
 
 sleep_well.description = {
-    "label": "sleep well..",
+    "label": "sleep well...",
     "help": "do nothing but sleep",
     "options": [
         {
